################################################################################
# Copyright (c) 2023 Mercedes-Benz Tech Innovation GmbH
#
# This program and the accompanying materials are made available under the terms
# of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
#
# SPDX-License-Identifier: EPL-2.0
################################################################################
#
# This module defines the following variables:
#  PROJECT_VERSION_STRING
#  The full version including the number of additional commits since the last
#  tag and an abbreviated object name for the current commit
#  PROJECT_VERSION
#  The semantic version number the current commit is based on
#
################################################################################

find_package(Git)

if(NOT GIT_FOUND)
  message(AUTHOR_WARNING "Git not found. Version information will not be available.")
  return()
endif()

execute_process(
  COMMAND ${GIT_EXECUTABLE} describe --tags --always
  WORKING_DIRECTORY ${PROJECT_SOURCE_DIR}
  RESULT_VARIABLE PROJECT_VERSION_RESULT
  OUTPUT_VARIABLE PROJECT_VERSION_STRING
  ERROR_QUIET OUTPUT_STRIP_TRAILING_WHITESPACE
)

if(PROJECT_VERSION_RESULT EQUAL 0)
  message(STATUS "${PROJECT_NAME} version: ${PROJECT_VERSION_STRING}")
  string(REGEX MATCH "[0-9]+\\.[0-9]+\\.[0-9]+" PROJECT_VERSION "${PROJECT_VERSION_STRING}")
else()
  message(AUTHOR_WARNING "Could not read version information from Git.")
endif()

if(EXISTS "${CMAKE_CURRENT_LIST_DIR}/VERSION.in")
  configure_file("${CMAKE_CURRENT_LIST_DIR}/VERSION.in" "${CMAKE_CURRENT_BINARY_DIR}/VERSION" @ONLY)
endif()
